# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["MediaResponse"]


class MediaResponse(BaseModel):
    url: str
    """The URL of the media"""
