# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.device_spec import DeviceSpec

__all__ = ["Profile"]


class Profile(BaseModel):
    id: str

    created_at: datetime = FieldInfo(alias="createdAt")

    name: str

    spec: DeviceSpec

    updated_at: datetime = FieldInfo(alias="updatedAt")

    user_id: str = FieldInfo(alias="userId")

    schema_: Optional[str] = FieldInfo(alias="$schema", default=None)
    """A URL to the JSON Schema for this object."""
