# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["TaskSendMessageParams"]


class TaskSendMessageParams(TypedDict, total=False):
    message: Required[str]
    """Message to send to the running agent"""
