# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from mobilerun import Mobilerun, AsyncMobilerun
from tests.utils import assert_matches_type
from mobilerun.types import (
    Device,
    DeviceListResponse,
    DeviceCountResponse,
)
from mobilerun._utils import parse_datetime

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestDevices:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create(self, client: Mobilerun) -> None:
        device = client.devices.create()
        assert_matches_type(Device, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: Mobilerun) -> None:
        device = client.devices.create(
            device_type="dedicated_physical_device",
            apps=["string"],
            carrier={
                "gsm_operator_alpha": "GsmOperatorAlpha",
                "gsm_operator_numeric": 0,
                "gsm_sim_operator_alpha": "GsmSimOperatorAlpha",
                "gsm_sim_operator_iso_country": "GsmSimOperatorIsoCountry",
                "gsm_sim_operator_numeric": 0,
                "persist_sys_timezone": "PersistSysTimezone",
            },
            files=["string"],
            identifiers={
                "bootloader_serial_number": "BootloaderSerialNumber",
                "identifier_android_id": "IdentifierAndroidID",
                "identifier_app_set_id": "IdentifierAppSetID",
                "identifier_bluetooth_mac": "IdentifierBluetoothMAC",
                "identifier_gaid": "IdentifierGAID",
                "identifier_gsfid": "IdentifierGSFID",
                "identifier_iccid": "IdentifierICCID",
                "identifier_imei": "IdentifierIMEI",
                "identifier_imsi": "IdentifierIMSI",
                "identifier_media_drmid": "IdentifierMediaDRMID",
                "identifier_meid": "IdentifierMEID",
                "identifier_phone_number": "IdentifierPhoneNumber",
                "identifier_serial": "IdentifierSerial",
                "identifier_wifi_mac": "IdentifierWifiMAC",
                "serial_number": "SerialNumber",
            },
            name="name",
            proxy={
                "host": "host",
                "password": "password",
                "port": 0,
                "user": "user",
            },
            smart_ip=True,
        )
        assert_matches_type(Device, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: Mobilerun) -> None:
        response = client.devices.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        device = response.parse()
        assert_matches_type(Device, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: Mobilerun) -> None:
        with client.devices.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            device = response.parse()
            assert_matches_type(Device, device, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Mobilerun) -> None:
        device = client.devices.retrieve(
            "deviceId",
        )
        assert_matches_type(Device, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Mobilerun) -> None:
        response = client.devices.with_raw_response.retrieve(
            "deviceId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        device = response.parse()
        assert_matches_type(Device, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Mobilerun) -> None:
        with client.devices.with_streaming_response.retrieve(
            "deviceId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            device = response.parse()
            assert_matches_type(Device, device, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Mobilerun) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `device_id` but received ''"):
            client.devices.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list(self, client: Mobilerun) -> None:
        device = client.devices.list()
        assert_matches_type(DeviceListResponse, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Mobilerun) -> None:
        device = client.devices.list(
            country="country",
            name="name",
            order_by="id",
            order_by_direction="asc",
            page=0,
            page_size=0,
            state=["creating"],
            type="dedicated_physical_device",
        )
        assert_matches_type(DeviceListResponse, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Mobilerun) -> None:
        response = client.devices.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        device = response.parse()
        assert_matches_type(DeviceListResponse, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Mobilerun) -> None:
        with client.devices.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            device = response.parse()
            assert_matches_type(DeviceListResponse, device, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_count(self, client: Mobilerun) -> None:
        device = client.devices.count()
        assert_matches_type(DeviceCountResponse, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_count(self, client: Mobilerun) -> None:
        response = client.devices.with_raw_response.count()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        device = response.parse()
        assert_matches_type(DeviceCountResponse, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_count(self, client: Mobilerun) -> None:
        with client.devices.with_streaming_response.count() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            device = response.parse()
            assert_matches_type(DeviceCountResponse, device, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_terminate(self, client: Mobilerun) -> None:
        device = client.devices.terminate(
            device_id="deviceId",
        )
        assert device is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_terminate_with_all_params(self, client: Mobilerun) -> None:
        device = client.devices.terminate(
            device_id="deviceId",
            previous_device_id="previousDeviceId",
            terminate_at=parse_datetime("2019-12-27T18:11:19.117Z"),
        )
        assert device is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_terminate(self, client: Mobilerun) -> None:
        response = client.devices.with_raw_response.terminate(
            device_id="deviceId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        device = response.parse()
        assert device is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_terminate(self, client: Mobilerun) -> None:
        with client.devices.with_streaming_response.terminate(
            device_id="deviceId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            device = response.parse()
            assert device is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_terminate(self, client: Mobilerun) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `device_id` but received ''"):
            client.devices.with_raw_response.terminate(
                device_id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_wait_ready(self, client: Mobilerun) -> None:
        device = client.devices.wait_ready(
            "deviceId",
        )
        assert_matches_type(Device, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_wait_ready(self, client: Mobilerun) -> None:
        response = client.devices.with_raw_response.wait_ready(
            "deviceId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        device = response.parse()
        assert_matches_type(Device, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_wait_ready(self, client: Mobilerun) -> None:
        with client.devices.with_streaming_response.wait_ready(
            "deviceId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            device = response.parse()
            assert_matches_type(Device, device, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_wait_ready(self, client: Mobilerun) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `device_id` but received ''"):
            client.devices.with_raw_response.wait_ready(
                "",
            )


class TestAsyncDevices:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncMobilerun) -> None:
        device = await async_client.devices.create()
        assert_matches_type(Device, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncMobilerun) -> None:
        device = await async_client.devices.create(
            device_type="dedicated_physical_device",
            apps=["string"],
            carrier={
                "gsm_operator_alpha": "GsmOperatorAlpha",
                "gsm_operator_numeric": 0,
                "gsm_sim_operator_alpha": "GsmSimOperatorAlpha",
                "gsm_sim_operator_iso_country": "GsmSimOperatorIsoCountry",
                "gsm_sim_operator_numeric": 0,
                "persist_sys_timezone": "PersistSysTimezone",
            },
            files=["string"],
            identifiers={
                "bootloader_serial_number": "BootloaderSerialNumber",
                "identifier_android_id": "IdentifierAndroidID",
                "identifier_app_set_id": "IdentifierAppSetID",
                "identifier_bluetooth_mac": "IdentifierBluetoothMAC",
                "identifier_gaid": "IdentifierGAID",
                "identifier_gsfid": "IdentifierGSFID",
                "identifier_iccid": "IdentifierICCID",
                "identifier_imei": "IdentifierIMEI",
                "identifier_imsi": "IdentifierIMSI",
                "identifier_media_drmid": "IdentifierMediaDRMID",
                "identifier_meid": "IdentifierMEID",
                "identifier_phone_number": "IdentifierPhoneNumber",
                "identifier_serial": "IdentifierSerial",
                "identifier_wifi_mac": "IdentifierWifiMAC",
                "serial_number": "SerialNumber",
            },
            name="name",
            proxy={
                "host": "host",
                "password": "password",
                "port": 0,
                "user": "user",
            },
            smart_ip=True,
        )
        assert_matches_type(Device, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncMobilerun) -> None:
        response = await async_client.devices.with_raw_response.create()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        device = await response.parse()
        assert_matches_type(Device, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncMobilerun) -> None:
        async with async_client.devices.with_streaming_response.create() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            device = await response.parse()
            assert_matches_type(Device, device, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncMobilerun) -> None:
        device = await async_client.devices.retrieve(
            "deviceId",
        )
        assert_matches_type(Device, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncMobilerun) -> None:
        response = await async_client.devices.with_raw_response.retrieve(
            "deviceId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        device = await response.parse()
        assert_matches_type(Device, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncMobilerun) -> None:
        async with async_client.devices.with_streaming_response.retrieve(
            "deviceId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            device = await response.parse()
            assert_matches_type(Device, device, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncMobilerun) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `device_id` but received ''"):
            await async_client.devices.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncMobilerun) -> None:
        device = await async_client.devices.list()
        assert_matches_type(DeviceListResponse, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncMobilerun) -> None:
        device = await async_client.devices.list(
            country="country",
            name="name",
            order_by="id",
            order_by_direction="asc",
            page=0,
            page_size=0,
            state=["creating"],
            type="dedicated_physical_device",
        )
        assert_matches_type(DeviceListResponse, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncMobilerun) -> None:
        response = await async_client.devices.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        device = await response.parse()
        assert_matches_type(DeviceListResponse, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncMobilerun) -> None:
        async with async_client.devices.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            device = await response.parse()
            assert_matches_type(DeviceListResponse, device, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_count(self, async_client: AsyncMobilerun) -> None:
        device = await async_client.devices.count()
        assert_matches_type(DeviceCountResponse, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_count(self, async_client: AsyncMobilerun) -> None:
        response = await async_client.devices.with_raw_response.count()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        device = await response.parse()
        assert_matches_type(DeviceCountResponse, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_count(self, async_client: AsyncMobilerun) -> None:
        async with async_client.devices.with_streaming_response.count() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            device = await response.parse()
            assert_matches_type(DeviceCountResponse, device, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_terminate(self, async_client: AsyncMobilerun) -> None:
        device = await async_client.devices.terminate(
            device_id="deviceId",
        )
        assert device is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_terminate_with_all_params(self, async_client: AsyncMobilerun) -> None:
        device = await async_client.devices.terminate(
            device_id="deviceId",
            previous_device_id="previousDeviceId",
            terminate_at=parse_datetime("2019-12-27T18:11:19.117Z"),
        )
        assert device is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_terminate(self, async_client: AsyncMobilerun) -> None:
        response = await async_client.devices.with_raw_response.terminate(
            device_id="deviceId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        device = await response.parse()
        assert device is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_terminate(self, async_client: AsyncMobilerun) -> None:
        async with async_client.devices.with_streaming_response.terminate(
            device_id="deviceId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            device = await response.parse()
            assert device is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_terminate(self, async_client: AsyncMobilerun) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `device_id` but received ''"):
            await async_client.devices.with_raw_response.terminate(
                device_id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_wait_ready(self, async_client: AsyncMobilerun) -> None:
        device = await async_client.devices.wait_ready(
            "deviceId",
        )
        assert_matches_type(Device, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_wait_ready(self, async_client: AsyncMobilerun) -> None:
        response = await async_client.devices.with_raw_response.wait_ready(
            "deviceId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        device = await response.parse()
        assert_matches_type(Device, device, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_wait_ready(self, async_client: AsyncMobilerun) -> None:
        async with async_client.devices.with_streaming_response.wait_ready(
            "deviceId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            device = await response.parse()
            assert_matches_type(Device, device, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_wait_ready(self, async_client: AsyncMobilerun) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `device_id` but received ''"):
            await async_client.devices.with_raw_response.wait_ready(
                "",
            )
